@@ -1,7 +1,8 @@
 from simpleMediaCenter.interface.Interface import Interface, ExceptionDisplayHandler
 from simpleMediaCenter.helpers.twitch import TwitchException
 from tg import expose, TGController, AppConfig, redirect, config
-from wsgiref.simple_server import make_server
+from wsgiref.simple_server import make_server, WSGIServer
+from socketserver import ThreadingMixIn
 import os
 import jinja2
 import logging
@@ -50,15 +51,25 @@ class WebController(TGController):
         self.updateStatus()
         self.__logger.debug(self.statusDict)
         return self.statusDict
+       
+    '''
+    #loading parking Page
+    @expose('loading.html')
+    def loading(self):
+        self.__logger.debug('loading called')
+        redirect("/")
+    '''    
         
     
     #controls
+    '''
+        play file, auto select suitable player
+    '''
     @expose()
     def play(self, id=None):
         try:
             id = self.parseID(id)
             self.__logger.debug("trying to play %s" ,self.browserList.getActive().getPlayable(id))
-            # TODO implement player select according to playlist.getSupportedPlayers()
             self.__logger.debug("searching for compatible Browser") 
             for supportedPlayer in self.browserList.getActive().getSupportedPlayers():
                 playerid = self.playerList.getIDfromName(supportedPlayer)
@@ -74,18 +85,45 @@ class WebController(TGController):
 
         redirect("/")
     
+    '''
+        stop playback
+    '''
     @expose()
     def stop(self):
         self.__logger.debug("stop called")
         self.playerList.getActive().stop()
         redirect("/")
-        
+      
+    '''
+        pause playback
+    '''
     @expose()
     def pause(self):
         self.__logger.debug("pause called")
         self.playerList.getActive().pause()
         redirect("/")
         
+    '''
+        reduces player volume
+    '''
+    @expose()
+    def volumedown(self):
+        self.__logger.debug("volume down called")
+        self.playerList.getActive().volumeDown()
+        redirect("/")
+        
+    '''
+        increases player volume
+    '''
+    @expose()
+    def volumeup(self):
+        self.__logger.debug("volume up called")
+        self.playerList.getActive().volumeUp()
+        redirect("/")
+        
+    '''
+        change working directory
+    '''
     @expose()
     def change(self,id=None):
         try:
@@ -100,6 +138,10 @@ class WebController(TGController):
             self.exceptionDisplayHandler.setException('Exception','Unhandled Exception in change: ' + repr(e))
         redirect("/")
         
+        
+    '''
+        search something which is then treated as a playable file
+    '''    
     @expose()
     def searchFile(self, search):
         self.__logger.debug("searchFile called")
@@ -108,6 +150,9 @@ class WebController(TGController):
             self.browserList.getActive().setWorkingDir(search, search='File')
         redirect("/")
         
+    '''
+        search something which is then treated as a browsable directory
+    '''
     @expose()
     def searchDir(self, search):
         self.__logger.debug("searchDir called")
@@ -116,7 +161,11 @@ class WebController(TGController):
             self.__logger.debug("browser Search enabled")
             self.browserList.getActive().setWorkingDir(search, search='Dir')
         redirect("/")
-        
+      
+    '''
+        DEPRECATED: is now done automatically
+        selects player via dropdown menu
+    '''      
     @expose()
     def selectPlayer(self, id=None):
         try:
@@ -126,7 +175,10 @@ class WebController(TGController):
         except Exception as e:
             self.exceptionDisplayHandler.setException('Exception','Unhandled Exception in selectPlayer: ' + repr(e))
         redirect("/")
-    
+        
+    '''
+        selects browser via dropdown menu
+    '''
     @expose()
     def selectBrowser(self, id=None):
         try:
@@ -136,6 +188,9 @@ class WebController(TGController):
             self.exceptionDisplayHandler.setException('Exception','Unhandled Exception in selectBrowser: ' + repr(e))
         redirect("/")
         
+    '''
+        selects playlist via dropdown menu
+    '''
     @expose()
     def selectPlaylist(self, id=None):
         try:
@@ -145,6 +200,9 @@ class WebController(TGController):
             self.exceptionDisplayHandler.setException('Exception','Unhandled Exception in selectPlaylist: ' + repr(e))
         redirect("/")
         
+    '''
+        clears an exception from memory
+    '''
     @expose()
     def clearException(self):
         self.exceptionDisplayHandler.clearException()
@@ -155,8 +213,10 @@ class WebController(TGController):
     def status(self,_=None):
         self.updateStatus()
         return json.dumps(self.statusDict)
-        
 
+        
+class ThreadingWSGIServer(ThreadingMixIn, WSGIServer): 
+    pass
 
 class WebInterface(Interface):
     __logger=logging.getLogger(__name__)
@@ -184,8 +244,11 @@ class WebInterface(Interface):
         self.config.serve_static = True
         self.config.paths['static_files'] = staticPath
         
+        #make wsgi_app      
         self.application = self.config.make_wsgi_app()
-        self.httpd = make_server('', port, self.application)
+        
+        #make wsgi_server
+        self.httpd = make_server('', port, self.application, ThreadingWSGIServer)
         self.httpd.timeout = 5
     
     def run(self):
@@ -193,15 +256,11 @@ class WebInterface(Interface):
         while(self.keep_running):
             self.__logger.debug("start serve_forever()")
             try:
-                #self.httpd.handle_request()
                 self.httpd.serve_forever()
             except KeyboardInterrupt:
                 self.shutdown()
-                
-        
+    
     def shutdown(self):
         self.__logger.info("init shutdown")
         self.controller.playerList.getActive().stop()
         self.keep_running=False
-        
-  
\ No newline at end of file
